==> v1.3.1.tar.gz: element-android/matrix-sdk-android/src/main/java/org/matrix/android/sdk/internal/query/QueryRoomOrderProcessor.kt <==
/*
 * Copyright 2021 The Matrix.org Foundation C.I.C.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.matrix.android.sdk.internal.query

import io.realm.RealmQuery
import io.realm.Sort
import org.matrix.android.sdk.api.session.room.RoomSortOrder
import org.matrix.android.sdk.internal.database.model.RoomSummaryEntity
import org.matrix.android.sdk.internal.database.model.RoomSummaryEntityFields

internal fun RealmQuery<RoomSummaryEntity>.process(sortOrder: RoomSortOrder): RealmQuery<RoomSummaryEntity> {
    when (sortOrder) {
        RoomSortOrder.NAME                  -> {
            sort(RoomSummaryEntityFields.DISPLAY_NAME, Sort.ASCENDING)
        }
        RoomSortOrder.ACTIVITY              -> {
            sort(RoomSummaryEntityFields.LAST_ACTIVITY_TIME, Sort.DESCENDING)
        }
        RoomSortOrder.PRIORITY_AND_ACTIVITY -> {
            sort(
                    arrayOf(
                            RoomSummaryEntityFields.IS_FAVOURITE,
                            RoomSummaryEntityFields.IS_LOW_PRIORITY,
                            RoomSummaryEntityFields.LAST_ACTIVITY_TIME),
                    arrayOf(Sort.DESCENDING, Sort.ASCENDING, Sort.DESCENDING))
        }
        RoomSortOrder.NONE                  -> {
        }
    }
    return this
}

==> v1.4.27.tar.gz: element-android/matrix-sdk-android/src/main/java/org/matrix/android/sdk/internal/query/QueryRoomOrderProcessor.kt <==
/*
 * Copyright 2021 The Matrix.org Foundation C.I.C.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.matrix.android.sdk.internal.query

import io.realm.RealmQuery
import io.realm.Sort
import org.matrix.android.sdk.api.session.room.RoomSortOrder
import org.matrix.android.sdk.internal.database.model.RoomSummaryEntity
import org.matrix.android.sdk.internal.database.model.RoomSummaryEntityFields

internal fun RealmQuery<RoomSummaryEntity>.process(sortOrder: RoomSortOrder): RealmQuery<RoomSummaryEntity> {
    when (sortOrder) {
        RoomSortOrder.NAME -> {
            sort(RoomSummaryEntityFields.DISPLAY_NAME, Sort.ASCENDING)
        }
        RoomSortOrder.ACTIVITY -> {
            sort(RoomSummaryEntityFields.LAST_ACTIVITY_TIME, Sort.DESCENDING)
        }
        RoomSortOrder.PRIORITY_AND_ACTIVITY -> {
            sort(
                    arrayOf(
                            RoomSummaryEntityFields.IS_FAVOURITE,
                            RoomSummaryEntityFields.IS_LOW_PRIORITY,
                            RoomSummaryEntityFields.LAST_ACTIVITY_TIME
                    ),
                    arrayOf(Sort.DESCENDING, Sort.ASCENDING, Sort.DESCENDING)
            )
        }
        RoomSortOrder.NONE -> {
        }
    }
    return this
}
